"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const index_1 = require("../crypto/index");
const Padder_1 = require("../Padder");
class Collector {
    constructor(map, numberOfSlices, verificationHash, hashEngine) {
        this.map = map;
        this.numberOfSlices = numberOfSlices;
        this.verificationHash = verificationHash;
        this.hashEngine = hashEngine;
        this.padder = new Padder_1.Padder();
    }
    /**
       * Test whether the passed data once hashed equals the verification hash
       *
       * @param data
       */
    check(data) {
        return index_1.hash(data.toString(), this.hashEngine)
            .then(hashedData => hashedData === this.verificationHash);
    }
    /**
       * @returns the concatenated slices into the obfuscated string
       */
    toObfuscated() {
        let o = '';
        for (let i = 0; i < this.numberOfSlices; i++) {
            const uncrumb = this.map.get(i);
            if (uncrumb === undefined) {
                throw new Error(`missing slice with index: ${i}`);
            }
            o += this.padder.unapply(uncrumb.toSlice());
        }
        return Buffer.from(o);
    }
}
exports.Collector = Collector;
